package com.example.julian.endlessroll.entities.tools;

import com.example.julian.endlessroll.data.Vector;
import com.example.julian.endlessroll.entities.DestroyEffect;
import com.example.julian.endlessroll.entities.Obstacle;
import com.example.julian.endlessroll.entities.Player;
import com.example.julian.endlessroll.entities.collision.CollisionDetector;
import com.example.julian.endlessroll.entities.collision.geometry.Geometry;
import com.example.julian.endlessroll.entities.collision.geometry.Quad;
import com.example.julian.endlessroll.main.game.Timer;

import java.util.List;

/**
 * Created by Julian on 20.02.2016.
 */
public class Bomb extends Tool {

    public final float RANGE = 1;
    private float delta;
    private boolean exploding = false;

    public Bomb(Vector position) {
        super(ToolType.BOMB, position, .29f, .29f, false, false);
        animation.setIndexSequence(new int[]{0, 1, 2});
        animation.setLooping(false);
        animation.setRequiredDelta(300);
    }

    @Override
    public void update(Timer timer) {
        super.update(timer);
        delta += timer.getFrameTime();
        if (delta >= 1000)
            exploding = true;
    }

    @Override
    public void onPlayerCollision(Player player) {

    }

    @Override
    protected Geometry createCollisionBounds() {
        return this;
    }

    public boolean isExploding() {
        return exploding;
    }

    public void explode(List<Obstacle> obstacles, CollisionDetector detector) {
        Quad explotionRange = new Quad(new Vector(super.getPosition()), RANGE, RANGE);
        for (Obstacle obstacle : obstacles) {
            if (detector.quadQuadCollision(obstacle, explotionRange))
                obstacle.destroy(DestroyEffect.EXPLOSION);
        }
        super.destroy(DestroyEffect.EXPLOSION);
    }
}
