package com.example.julian.endlessroll.main.screens;

import android.graphics.Typeface;
import android.support.annotation.IdRes;
import android.view.View;
import android.view.animation.AnimationUtils;
import android.widget.Button;
import android.widget.RelativeLayout;
import android.widget.ToggleButton;

import com.example.julian.endlessroll.R;
import com.example.julian.endlessroll.levels.LevelManager;
import com.example.julian.endlessroll.main.GameActivity;
import com.example.julian.endlessroll.main.MyGlSurfaceView;
import com.example.julian.endlessroll.main.game.User;
import com.example.julian.endlessroll.rendering.Rendering;
import com.example.julian.endlessroll.sounds.SoundManager;

/**
 * Created by Julian on 07.07.2016.
 */
public class StartScreen extends GLScreen<RelativeLayout> implements View.OnClickListener {

    private GameActivity activity;
    private SoundManager soundManager;
    private LevelManager levelManager;
    private User user;
    private Rendering rendering;

    private Button play;
    private Button lvUp;
    private Button lv100;
    private ToggleButton soundToggle;

    public StartScreen(GameActivity activity, MyGlSurfaceView glSurfaceView, SoundManager soundManager, LevelManager levelManager, User user, Typeface typeface) throws Exception {
        super(ScreenType.START, activity, R.layout.start_screen, glSurfaceView);
        this.activity = activity;
        this.soundManager = soundManager;
        this.levelManager = levelManager;
        this.user = user;

        play = createButton(R.id.startscreen_play, typeface);
        play.startAnimation(AnimationUtils.loadAnimation(activity, R.anim.rotate));
        lvUp = createButton(R.id.startscreen_comingsoon, typeface);
        lv100 = createButton(R.id.startscreen_maxcheat, typeface);
        soundToggle = (ToggleButton) layout.findViewById(R.id.startscreen_sound);
        soundToggle.setTypeface(typeface);
        soundToggle.setOnClickListener(this);
        soundToggle.setChecked(soundManager.isSoundOn());

        rendering = new StartScreenRendering(activity);
        glView.addRendering(rendering);
    }

    private Button createButton(@IdRes int id, Typeface typeface) {
        Button button = (Button) layout.findViewById(id);
        button.setTypeface(typeface);
        button.setOnClickListener(this);
        return button;
    }

    @Override
    public void prepareToBeShown() {
        glView.setCurrentRendering(rendering);
        if (soundToggle != null)
            soundToggle.setChecked(soundManager.isSoundOn());
    }

    @Override
    public void onBackKeyDown() {
        activity.finish();
    }

    @Override
    public void onClick(View v) {
        if (v.equals(play)) {
            activity.flipToScreen(ScreenType.WORLDS);
            glView.setCurrentRendering(null);
        } else if (v.equals(soundToggle)) {
            soundManager.setSoundOn(soundToggle.isChecked());
        } else if (v.equals(lv100)) {
            //user.setLevel(100);
//            user.setStarCount(100);
            levelManager.unlockAllLevels();
            levelManager.unlockAllPacks();
            user.gainEp(75);
        } else if (v.equals(lvUp)) {
            user.gainEp(100);
        }
    }


}
