package com.example.julian.endlessroll.main.screens;

import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;

import com.example.julian.endlessroll.R;
import com.example.julian.endlessroll.levels.LevelManager;
import com.example.julian.endlessroll.levels.LevelPack;
import com.example.julian.endlessroll.main.GameActivity;
import com.example.julian.endlessroll.views.TopBar;
import com.example.julian.endlessroll.views.TopBarData;
import com.example.julian.endlessroll.views.WorldButton;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by Julian on 07.07.2016.
 */
public class WorldsScreen extends Screen<RelativeLayout> implements View.OnClickListener {

    private LevelManager levelManager;
    private GameActivity activity;

    private TopBar topBar;
    private LinearLayout buttonLayout;
    private List<WorldButton> worldButtons = new ArrayList<>();

    public WorldsScreen(TopBarData topBarData) {
        super(ScreenType.WORLDS, topBarData.getGameActivity(), R.layout.worlds);
        this.activity = topBarData.getGameActivity();
        this.levelManager = topBarData.getLevelManager();
        topBar = new TopBar(topBarData, ScreenType.WORLDS, (RelativeLayout) layout.findViewById(R.id.worlds_topbar));
        buttonLayout = (LinearLayout) layout.findViewById(R.id.worlds_layout);
        LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT);
        params.setMargins(25, 0, 25, 0);

        for (LevelPack levelPack : levelManager) {
            WorldButton button = new WorldButton(activity, topBarData.getTypeface(), this, levelPack);
            buttonLayout.addView(button, params);
            worldButtons.add(button);
        }
    }

    @Override
    public void prepareToBeShown() {
        topBar.update();
        for (WorldButton button : worldButtons) {
            button.updateInformation();
        }
    }

    @Override
    public void onBackKeyDown() {
        activity.flipToScreen(ScreenType.START);
    }

    @Override
    public void onClick(View v) {
        for (WorldButton button : worldButtons) {
            if (v.equals(button) && !button.isLocked()) {
                LevelPack levelPack = button.getLevelPack();
                activity.selectWorld(levelPack);
                activity.flipToScreen(ScreenType.LEVELS);
            }
        }
    }
}
