package com.example.julian.endlessroll.sqlDatabase;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;

import com.example.julian.endlessroll.entities.tools.ToolType;
import com.example.julian.endlessroll.levels.Level;
import com.example.julian.endlessroll.levels.LevelPack;

/**
 * Created by Julian on 10.05.2016.
 */
public class MyDatabase extends DatabaseAdapter {

    private final static int VERSION = 7;
    private final static String DATABASE_NAME = "DATABASE";
    private SQLTableColumn levelpackColumn, levelColumn, lockedColumn, finishedColumn, starsColumn, energyColumn;
    private SQLTableColumn toolIdColumn, boughtColumn;
    private SQLTable levelTable, levelPackTable, toolTable;

    public MyDatabase(Context context) {
        super(context, DATABASE_NAME, VERSION);
    }

    @Override
    protected void createColumns() {
        levelpackColumn = new SQLTableColumn("LEVELPACK", SQLTableColumn.ColumnType.INTEGER, SQLTableColumn.ColumnExtra.NOT_NULL);
        levelColumn = new SQLTableColumn("LEVEL", SQLTableColumn.ColumnType.INTEGER, SQLTableColumn.ColumnExtra.NOT_NULL);
        lockedColumn = new SQLTableColumn("LOCKED", SQLTableColumn.ColumnType.INTEGER, SQLTableColumn.ColumnExtra.NOT_NULL);
        finishedColumn = new SQLTableColumn("FINISHED", SQLTableColumn.ColumnType.INTEGER, SQLTableColumn.ColumnExtra.NOT_NULL);
        starsColumn = new SQLTableColumn("STARS", SQLTableColumn.ColumnType.TEXT, SQLTableColumn.ColumnExtra.NOT_NULL);
        energyColumn = new SQLTableColumn("ENERGY", SQLTableColumn.ColumnType.INTEGER, SQLTableColumn.ColumnExtra.NOT_NULL);

        toolIdColumn = new SQLTableColumn("TOOL_ID", SQLTableColumn.ColumnType.INTEGER, SQLTableColumn.ColumnExtra.NOT_NULL);
        boughtColumn = new SQLTableColumn("BOUGHT", SQLTableColumn.ColumnType.INTEGER, SQLTableColumn.ColumnExtra.NOT_NULL);
    }

    @Override
    protected SQLTable[] createTables() {
        levelPackTable = new SQLTable("LEVELPACK_TABLE", levelpackColumn, lockedColumn);
        levelTable = new SQLTable("LEVEL_TABLE", levelpackColumn, levelColumn, lockedColumn, finishedColumn, starsColumn, energyColumn);
        toolTable = new SQLTable("TOOL_TABLE", toolIdColumn, boughtColumn);
        return new SQLTable[]{levelPackTable, levelTable, toolTable};
    }

    public void writeLevelProgress(Level level) {
        ContentValues values = new ContentValues();
        values.put(levelpackColumn.getKey(), level.getPackId());
        values.put(levelColumn.getKey(), level.getId());
        values.put(lockedColumn.getKey(), level.isLocked() ? 1 : 0);
        values.put(finishedColumn.getKey(), level.isFinished() ? 1 : 0);
        values.put(starsColumn.getKey(), level.getCollectedStarCodeForSQL());
        values.put(energyColumn.getKey(), level.isEnergyCollected());
        long update = super.update(levelTable, values, levelpackColumn, level.getPackId(), levelColumn, level.getId());
    }

    public void readLevelProgress(Level level) {
        Cursor cursor = super.getCursor(levelTable, levelpackColumn, level.getPackId(), levelColumn, level.getId());
        if (cursor.moveToFirst()) {
            boolean locked = cursor.getInt(2) == 1;
            boolean finished = cursor.getInt(3) == 1;
            String stars = cursor.getString(4);
            boolean energy = cursor.getInt(5) == 1;

            level.setLocked(locked);
            level.setFinished(finished);
            level.setCollectedStarsFromSQL(stars);
            level.setEnergyCollected(energy);
        }
        cursor.close();
    }

    public void clearLevelProgess() {
        super.clearTable(levelTable);
    }

    public void writeLevelPackLocked(LevelPack levelPack) {
        ContentValues values = new ContentValues();
        values.put(levelpackColumn.getKey(), levelPack.getId());
        values.put(lockedColumn.getKey(), levelPack.isLocked() ? 1 : 0);
        super.update(levelPackTable, values, levelpackColumn, levelPack.getId());
    }

    public void readLevelPackLocked(LevelPack levelPack) {
        Cursor cursor = super.getCursor(levelPackTable, levelpackColumn, levelPack.getId());
        if (cursor.moveToFirst()) {
            boolean locked = cursor.getInt(1) == 1;
            levelPack.setLocked(locked);
        } else {
            levelPack.setLocked(true);
        }
        cursor.close();
    }

    public void writeBoughtTools() {
        for (ToolType tool : ToolType.values()) {
            if (tool != ToolType.NONE) {
                ContentValues values = new ContentValues();
                values.put(toolIdColumn.getKey(), tool.ordinal());
                values.put(boughtColumn.getKey(), tool.isBought() ? 1 : 0);
                super.update(toolTable, values, toolIdColumn, tool.ordinal());
            }
        }
    }

    public void readBoughtTools() {
        Cursor cursor = super.getCursor(toolTable);
        if (cursor.moveToFirst()) {
            do {
                int id = cursor.getInt(0);
                boolean bought = cursor.getInt(1) == 1;
                ToolType.values()[id].setBought(bought);
            }
            while (cursor.moveToNext());
        }
        cursor.close();
    }

}
