package com.example.julian.endlessroll.views;

import android.graphics.Typeface;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.example.julian.endlessroll.R;
import com.example.julian.endlessroll.levels.levelup.LevelBounty;
import com.example.julian.endlessroll.main.GameActivity;
import com.example.julian.endlessroll.main.GameLog;
import com.example.julian.endlessroll.main.game.User;
import com.example.julian.endlessroll.main.screens.Screen;

/**
 * Created by Julian on 15.07.2016.
 */
public class LevelupMessage implements View.OnClickListener, BountyMessage.ScreenSwitchCaller {

    private GameActivity gameActivity;
    private User user;
    private FrameLayout layout;

    private TextView levelView;
    private TextView text;
    private LinearLayout unlockMessages;

    public LevelupMessage(GameActivity gameActivity, Typeface typeface, User user) {
        this.gameActivity = gameActivity;
        this.user = user;

        LayoutInflater inflater = LayoutInflater.from(gameActivity);
        layout = (FrameLayout) inflater.inflate(R.layout.levelup_message, null);
        layout.setOnClickListener(this);
        layout.setLayoutParams(new ViewGroup.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT));
        layout.setVisibility(View.GONE);
        levelView = (TextView) layout.findViewById(R.id.levelup_level);
        levelView.setTypeface(typeface);
        text = (TextView) layout.findViewById(R.id.levelup_text);
        text.setTypeface(typeface);
        unlockMessages = (LinearLayout) layout.findViewById(R.id.levelup_unlocklist);
    }

    public void show(int level) {
        LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT);
        params.setMargins(0, 5, 0, 5);

        levelView.setText(level + "");
        layout.setVisibility(View.VISIBLE);

        LevelBounty bounty = user.getLevelUpBounties().get(level);
        if (bounty != null)
            for (BountyMessage message : bounty.createBountyMessages(gameActivity, this))
                unlockMessages.addView(message.getLayout(), params);
    }

    private void hide() {
        layout.clearAnimation();
        layout.setVisibility(View.GONE);
        unlockMessages.removeAllViews();
    }

    public FrameLayout getLayout() {
        return layout;
    }

    @Override
    public void onClick(View v) {
        hide();
    }


    @Override
    public void switchScreen(Screen.ScreenType screenType) {
        if (screenType == Screen.ScreenType.TOOL_SHOP)
            gameActivity.setToolshopCaller(gameActivity.getCurrentScreenType());
        gameActivity.flipToScreen(screenType);
        hide();
    }
}
