package com.example.julian.endlessroll.views;

import android.content.Context;
import android.graphics.Typeface;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.example.julian.endlessroll.R;
import com.example.julian.endlessroll.levels.LevelPack;
import com.example.julian.endlessroll.levels.worlds.Theme;

/**
 * Created by Julian on 01.08.2016.
 */
public class WorldButton extends RelativeLayout {

    private LevelPack levelPack;
    private Theme theme;

    private TextView title;
    private ImageView previewImage;
    private ImageView lockImage;
    private TextView levelCount;
    private TextView starCount;
    private TextView energyCount;

    public WorldButton(Context context, Typeface typeface, View.OnClickListener clickListener, LevelPack levelPack) {
        super(context);
        this.levelPack = levelPack;
        this.theme = levelPack.getTheme();

        LayoutInflater inflater = LayoutInflater.from(context);
        inflater.inflate(R.layout.world_button, this);
        super.setOnClickListener(clickListener);

        title = (TextView) super.findViewById(R.id.worldbutton_title);
        title.setTypeface(typeface);
        previewImage = (ImageView) super.findViewById(R.id.worldbutton_preview);
        lockImage = (ImageView) super.findViewById(R.id.worldbutton_lock);
        levelCount = (TextView) super.findViewById(R.id.worldbutton_levelcount);
        levelCount.setTypeface(typeface);
        starCount = (TextView) super.findViewById(R.id.worldbutton_starcount);
        starCount.setTypeface(typeface);
        energyCount = (TextView) super.findViewById(R.id.worldbutton_energycount);
        energyCount.setTypeface(typeface);

        updateInformation();
    }

    public void updateInformation() {
        title.setText(levelPack.getName());
        previewImage.setImageDrawable(getContext().getResources().getDrawable(theme.getPreviewId()));
        levelCount.setText(levelPack.getFinishedLevelCount() + "/" + levelPack.getLevels().size());
        starCount.setText(levelPack.getCollectedStarCount() + "/" + levelPack.getAvailableStars());
        energyCount.setText(levelPack.getCollectedEnergyCount() + "/" + levelPack.getAvailableEnergy());
        setLockVisible(levelPack.isLocked());
    }

    public void setLockVisible(boolean locked) {
        int visibility = locked ? VISIBLE : INVISIBLE;
        lockImage.setVisibility(visibility);
    }

    public boolean isLocked() {
        if (lockImage.getVisibility() == VISIBLE)
            return true;
        return false;
    }

    public LevelPack getLevelPack() {
        return levelPack;
    }
}
